"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.memoize = exports.memo = exports.tap = exports.identity = exports.noop = void 0;
const noop = () => { };
exports.noop = noop;
const identity = (x) => x;
exports.identity = identity;
const tap = (tappingFunction) => {
    return (x) => {
        tappingFunction(x);
        return x;
    };
};
exports.tap = tap;
/** Returns a cached version of a function. Only caches one result. */
function memo(fn) {
    let cachedValue;
    return (...args) => {
        if (!cachedValue) {
            cachedValue = fn(...args);
        }
        return cachedValue;
    };
}
exports.memo = memo;
function memoize(fn, keyFn) {
    const cache = {};
    return (arg) => {
        const key = keyFn(arg);
        if (!cache[key]) {
            cache[key] = fn(arg);
        }
        return cache[key];
    };
}
exports.memoize = memoize;
//# sourceMappingURL=utils.js.map